==> kdevelop-24.02.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/KDevPlatform/KDevPlatformConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KDevPlatformConfig.cmake.in                            ########

get_filename_component(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_1 "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KDevPlatform" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_1 "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(KDEV_PLUGIN_VERSION 513)

include("${CMAKE_CURRENT_LIST_DIR}/KDevPlatformMacros.cmake")

include(CMakeFindDependencyMacro)



find_dependency(KF5TextEditor "5.91.0")
find_dependency(KF5ThreadWeaver "5.91.0")

include("${CMAKE_CURRENT_LIST_DIR}/KDevPlatformTargets.cmake")

==> kdevelop-25.04.1-2-x86_64.pkg.tar.zst: usr/lib/cmake/KDevPlatform/KDevPlatformConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KDevPlatformConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KDevPlatform" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(KDEV_PLUGIN_VERSION 62)

include("${CMAKE_CURRENT_LIST_DIR}/KDevPlatformMacros.cmake")

include(CMakeFindDependencyMacro)



find_dependency(KF6TextEditor "6.0.0")
find_dependency(KF6ThreadWeaver "6.0.0")

find_dependency(Qt6Core5Compat "6.5.0")
find_dependency(Qt6WebEngineWidgets "6.5.0") # for libKDevPlatformDocumentation

include("${CMAKE_CURRENT_LIST_DIR}/KDevPlatformTargets.cmake")
